Crate colours

Crate colours 

Generic color manipulation library

This crate implements widely used color types of different color models with conversions between it.

Each type can be parametrized by scalar type which will be used as channel or color component.

Modules

byte
Color types aliases parametrized with u8 type
float
Color types aliases parametrized with f32 type

Structs

Hsl
Generic HSL color
Hsla
Generic HSL color type with alpha component
Hsv
Generic HSV color
Hsva
Generic HSV color with alpha component
Rgb
Generic RGB color
Rgba
Generic RGB color with alpha component

Traits

HasAlpha
The color which has an alpha component
HasntAlpha
The color which has not alpha component
IsColor
Something which can be treated as color
IsColorChannel
Something which can be color channel