Generic color manipulation library
This crate implements widely used color types of different color models with conversions between it.
Each type can be parametrized by scalar type which will be used as channel or color component.
Modules
- byte
- Color types aliases parametrized with
u8type - float
- Color types aliases parametrized with
f32type
Structs
- Hsl
- Generic HSL color
- Hsla
- Generic HSL color type with alpha component
- Hsv
- Generic HSV color
- Hsva
- Generic HSV color with alpha component
- Rgb
- Generic RGB color
- Rgba
- Generic RGB color with alpha component
Traits
- HasAlpha
- The color which has an alpha component
- Hasnt
Alpha - The color which has not alpha component
- IsColor
- Something which can be treated as color
- IsColor
Channel - Something which can be color channel